# R3XA
## Remember, Reuse and Replicate eXperiments and Analyses

### Specs
- html: https://photomecanics.gitlab.io/r3xa/doc/
- json: https://gitlab.com/photomecanics/r3xa/-/raw/main/resources/schema.json

### Software
- packages: https://gitlab.com/photomecanics/r3xa/-/packages
- releases: https://gitlab.com/photomecanics/r3xa/-/releases

### Disclamer
This project is under developement. The specs are not complete.

### Install
```
pip install r3xa
```

### Command lines
```bash
# check validity of json faile
r3xa-validate my-metadata.json

# launch the gui to build a metadata file from scratch
r3xa

# launch the gui to see or modify an existing metadata file
r3xa --json my-metadata.json
```
